@@ -1,13 +1,13 @@
 /* io.h - I/O operations */
  
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef IO_H
 #define IO_H
 
 #include <sys/socket.h> /* for struct sockaddr */
-#include <linux/atm.h> /* for struct sockaddr_atmsvc */
+#include <atm.h> /* for struct sockaddr_atmsvc */
 
 
 void open_all(void);
