@@ -1,6 +1,6 @@
 /* table.c - ATMARP table */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
@@ -147,7 +147,7 @@ static void dump_entries(ENTRY *list)
 	"???",	"com", "PERM", "PUBL",			/* 0x0001-0x0008 */
 	"trailers", "netmask", "dontpub", "magic",	/* 0x0010-0x0080 */
 	"???", "???", "???", "???",			/* 0x0100-0x0800 */
-	"NULL", "ARPSRV", "NOVC" };			/* 0x1000-0x8000 */
+	"NULL", "ARPSRV", "NOVC", "???" };		/* 0x1000-0x8000 */
     /* lower case flags are not used by ATMARP */
     ENTRY *entry;
     char addr_buf[MAX_ATM_ADDR_LEN+1];
