@@ -1,20 +1,24 @@
 /*
  * q_atm.c		ATM.
  *
- * Hacked 1998 by Werner Almesberger, EPFL ICA
+ * Hacked 1998,1999 by Werner Almesberger, EPFL ICA
  *
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <syslog.h>
 #include <fcntl.h>
 #include <sys/socket.h>
+#include <sys/ioctl.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <string.h>
 #include <atm.h>
+#include <linux/atmdev.h>
+#include <linux/atmarp.h>
 
 #include "utils.h"
 #include "tc_util.h"
@@ -38,7 +42,8 @@ static int atm_parse_opt(struct qdisc_util *qu, int argc, char **argv, struct nl
 static void explain(void)
 {
 	fprintf(stderr, "Usage: ... atm ( pvc ADDR | svc ADDR [ sap SAP ] ) "
-	    "[ qos QOS ] [ hdr HEX... ] [ excess ( CLASSID | clp ) ] \n");
+	    "[ qos QOS ] [ hdr HEX... ]\n");
+	fprintf(stderr, "  [ excess ( CLASSID | clp ) ] [ clip ]\n");
 }
 
 
@@ -52,6 +57,7 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 	__u32 excess = 0;
 	struct rtattr *tail;
 	int hdr_len = -1;
+	int set_clip = 0;
 	int s;
 
 	memset(&addr,0,sizeof(addr));
@@ -122,6 +128,9 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 					return -1;
 				}
 		}
+		else if (!strcmp(*argv,"clip")) {
+			set_clip = 1;
+		}
 		else {
 			explain();
 			return 1;
@@ -148,6 +157,11 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 		perror("connect");
 		return -1;
 	}
+	if (set_clip)
+		if (ioctl(s,ATMARP_MKIP,0) < 0) {
+			perror("ioctl ATMARP_MKIP");
+			return -1;
+		}
 	tail = (struct rtattr *) (((void *) n)+NLMSG_ALIGN(n->nlmsg_len));
 	addattr_l(n,1024,TCA_OPTIONS,NULL,0);
 	addattr_l(n,1024,TCA_ATM_FD,&s,sizeof(s));
@@ -203,6 +217,17 @@ static int atm_print_opt(struct qdisc_util *qu, FILE *f, struct rtattr *opt)
 			}
 		}
 	}
+	if (tb[TCA_ATM_STATE]) {
+		static const char *map[] = { ATM_VS2TXT_MAP };
+		int state;
+
+		if (RTA_PAYLOAD(tb[TCA_ATM_STATE]) < sizeof(state))
+			fprintf(stderr,"ATM: state field too short\n");
+		else {
+			state = *(int *) RTA_DATA(tb[TCA_ATM_STATE]);
+			fprintf(f,"%s ",map[state]);
+		}
+	}
 	return 0;
 }
 
