@@ -35,6 +35,12 @@ static Q_DSC in_dsc;
 static TIMER *t309 = NULL;
 
 
+static unsigned short cvt_ep_ref(SIG_ENTITY *sig,unsigned short ep_ref)
+{
+    return sig->uni == S_UNI30 ? ep_ref & 0x7fff : ep_ref ^ 0x8000;
+}
+
+
 int send_call_proceeding(SOCKET *sock)
 {
     Q_DSC dsc;
@@ -103,7 +109,7 @@ static void setup_call(SIG_ENTITY *sig,unsigned long call_ref)
     this->call_state = cs_in_proc;
     this->call_ref = call_ref;
     if (q_present(&in_dsc,QF_ep_ref))
-	this->ep_ref = q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000;
+	this->ep_ref = cvt_ep_ref(sig,q_fetch(&in_dsc,QF_ep_ref));
 #ifdef CISCO
     else
 #endif
@@ -256,7 +262,7 @@ static void send_restart_ack(SIG_ENTITY *sig,int vpi,int vci)
 
 
 static void send_drop_party_ack(SIG_ENTITY *sig,unsigned long call_ref,
-  short ep_ref,unsigned char cause)
+  unsigned short ep_ref,unsigned char cause)
 {
     Q_DSC dsc;
     int size;
@@ -753,12 +759,15 @@ static void process_uni(SIG_ENTITY *sig,void *msg)
 	return;
     }
     if (curr && q_present(&in_dsc,QF_ep_ref) && mid != ATM_MSG_ADD_PARTY &&
-      mid != ATM_MSG_DROP_PARTY_ACK)
-	if (curr->ep_ref != (q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000)) {
-	    send_drop_party_ack(sig,call_ref,
-	      q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000,ATM_CV_INV_EPR);
+      mid != ATM_MSG_DROP_PARTY_ACK) {
+	unsigned short ep_ref;
+
+	ep_ref = cvt_ep_ref(sig,q_fetch(&in_dsc,QF_ep_ref));
+	if (curr->ep_ref != ep_ref) {
+	    send_drop_party_ack(sig,call_ref,ep_ref,ATM_CV_INV_EPR);
 	    return;
 	}
+    }
     if (!curr || curr->call_state == cs_null) {
 	if (mid != ATM_MSG_REL_COMP)
 	    if (mid != ATM_MSG_STATUS)
